# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .get_history_agents_response_contents_item_role import GetHistoryAgentsResponseContentsItemRole


class GetHistoryAgentsResponseContentsItem(UncheckedBaseModel):
    role: typing.Optional[GetHistoryAgentsResponseContentsItemRole] = pydantic.Field(default=None)
    """
    The message sender:
    - `user`: User
    - `assistant`: AI agent
    """

    content: typing.Optional[str] = pydantic.Field(default=None)
    """
    Message content.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
