# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .start_agents_request_properties_filler_words_content import StartAgentsRequestPropertiesFillerWordsContent
from .start_agents_request_properties_filler_words_trigger import StartAgentsRequestPropertiesFillerWordsTrigger


class StartAgentsRequestPropertiesFillerWords(UncheckedBaseModel):
    """
    Filler word configuration. Plays filler words while waiting for LLM responses to reduce user anxiety and improve conversation flow.
    """

    enable: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to enable filler words:
    - `true`: Enable filler words.
    - `false`: Disable filler words.
    """

    trigger: typing.Optional[StartAgentsRequestPropertiesFillerWordsTrigger] = pydantic.Field(default=None)
    """
    Filler word trigger configuration. Defines when to trigger filler word playback.
    """

    content: typing.Optional[StartAgentsRequestPropertiesFillerWordsContent] = pydantic.Field(default=None)
    """
    Filler word content configuration. Defines the source and selection rules for filler words.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
