# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel


class StartAgentsRequestPropertiesFillerWordsTriggerFixedTimeConfig(UncheckedBaseModel):
    """
    Fixed time trigger configuration. Used when `mode` is `fixed_time`.
    """

    response_wait_ms: typing.Optional[int] = pydantic.Field(default=None)
    """
    LLM response wait threshold in milliseconds. Triggers filler word playback when the LLM waits this duration without generating a response.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
