# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .update_agents_request_properties_llm import UpdateAgentsRequestPropertiesLlm
from .update_agents_request_properties_mllm import UpdateAgentsRequestPropertiesMllm


class UpdateAgentsRequestProperties(UncheckedBaseModel):
    """
    Configuration properties to update.
    """

    token: typing.Optional[str] = pydantic.Field(default=None)
    """
    The authentication token used by the agent to join the channel.
    """

    llm: typing.Optional[UpdateAgentsRequestPropertiesLlm] = pydantic.Field(default=None)
    """
    Large Language Model (LLM) settings.
    """

    mllm: typing.Optional[UpdateAgentsRequestPropertiesMllm] = pydantic.Field(default=None)
    """
    Multimodal Large Language Model (MLLM) configuration for real-time audio and text processing.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
