# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .start_agents_request_properties_geofence_area import StartAgentsRequestPropertiesGeofenceArea
from .start_agents_request_properties_geofence_exclude_area import StartAgentsRequestPropertiesGeofenceExcludeArea


class StartAgentsRequestPropertiesGeofence(UncheckedBaseModel):
    """
    Regional access restriction configuration. Use this to limit which Agora servers the Conversational AI Engine can access based on geographic regions.
    """

    area: StartAgentsRequestPropertiesGeofenceArea = pydantic.Field()
    """
    The allowed region for server access.
    """

    exclude_area: typing.Optional[StartAgentsRequestPropertiesGeofenceExcludeArea] = pydantic.Field(default=None)
    """
    The excluded region. Only available when `area` is set to `GLOBAL`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
