# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .google_tts_params import GoogleTtsParams


class GoogleTts(UncheckedBaseModel):
    """
    Google Text-to-Speech configuration (Beta).
    """

    params: GoogleTtsParams
    skip_patterns: typing.Optional[typing.List[int]] = pydantic.Field(default=None)
    """
    Controls whether the TTS module skips bracketed content when reading LLM response text.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
