# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from . import agents, agentkit, core, phone_numbers, telephony
    from .core.domain import Area, Pool, create_pool
    from .pool_client import Agora, AsyncAgora
    from .version import __version__
    from .agentkit import (
        Agent,
        AgentSession,
        AgentSessionOptions,
        generate_rtc_token,
        GenerateTokenOptions,
    )
    from .agentkit.agent_session import AsyncAgentSession
_dynamic_imports: typing.Dict[str, str] = {
    "Agora": ".pool_client",
    "Agent": ".agentkit",
    "AgentSession": ".agentkit",
    "AgentSessionOptions": ".agentkit",
    "Area": ".core.domain",
    "AsyncAgentSession": ".agentkit.agent_session",
    "AsyncAgora": ".pool_client",
    "GenerateTokenOptions": ".agentkit",
    "Pool": ".core.domain",
    "__version__": ".version",
    "agentkit": ".agentkit",
    "agents": ".agents",
    "core": ".core",
    "create_pool": ".core.domain",
    "generate_rtc_token": ".agentkit",
    "phone_numbers": ".phone_numbers",
    "telephony": ".telephony",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Agora",
    "Agent",
    "AgentSession",
    "AgentSessionOptions",
    "Area",
    "AsyncAgentSession",
    "AsyncAgora",
    "GenerateTokenOptions",
    "Pool",
    "__version__",
    "agentkit",
    "agents",
    "core",
    "create_pool",
    "generate_rtc_token",
    "phone_numbers",
    "telephony",
]
