# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .start_agents_request_properties_filler_words_content_static_config_selection_rule import (
    StartAgentsRequestPropertiesFillerWordsContentStaticConfigSelectionRule,
)


class StartAgentsRequestPropertiesFillerWordsContentStaticConfig(UncheckedBaseModel):
    """
    Static filler word configuration. Used when `mode` is `static`.
    """

    phrases: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of filler word phrases. Maximum 100 filler words, each not exceeding 50 English words.
    """

    selection_rule: typing.Optional[StartAgentsRequestPropertiesFillerWordsContentStaticConfigSelectionRule] = (
        pydantic.Field(default=None)
    )
    """
    Filler word selection rule:
    - `shuffle`: Random shuffle. Already-used filler words are not repeated until all have been used once.
    - `round_robin`: Round-robin. Selects and plays filler words sequentially from the list.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
