# This file was auto-generated by Fern from our API Definition.

import typing

StartAgentsRequestPropertiesTurnDetectionType = typing.Union[
    typing.Literal["agora_vad", "server_vad", "semantic_vad"], typing.Any
]
