# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from .list_telephony_response_data_list_item import ListTelephonyResponseDataListItem


class ListTelephonyResponseData(UncheckedBaseModel):
    """
    Call data object.
    """

    count: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of calls returned in this response.
    """

    list_: typing_extensions.Annotated[typing.List[ListTelephonyResponseDataListItem], FieldMetadata(alias="list")] = (
        pydantic.Field()
    )
    """
    A list of calls that meet the criteria.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
