# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class SarvamTtsParams(UncheckedBaseModel):
    """
    Sarvam TTS configuration parameters.
    """

    key: str = pydantic.Field()
    """
    Sarvam API subscription key
    """

    speaker: str = pydantic.Field()
    """
    Voice ID (e.g., anushka, abhilash, karun, hitesh, manisha, vidya, arya)
    """

    target_language_code: str = pydantic.Field()
    """
    Target language code (e.g., en-IN)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
