# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .start_agents_request_properties_llm_greeting_configs_mode import (
    StartAgentsRequestPropertiesLlmGreetingConfigsMode,
)


class StartAgentsRequestPropertiesLlmGreetingConfigs(UncheckedBaseModel):
    """
    Agent greeting broadcast configuration.
    """

    mode: typing.Optional[StartAgentsRequestPropertiesLlmGreetingConfigsMode] = pydantic.Field(default=None)
    """
    Determines when the agent sends greeting messages to users joining the channel.
    - `single_every`: Broadcasts a greeting every time a user joins the channel.
    - `single_first`: Broadcasts a greeting only once to the first user who joins the channel.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
