# This file was auto-generated by Fern from our API Definition.

import typing

StartAgentsRequestPropertiesTurnDetectionConfigStartOfSpeechDisabledConfigStrategy = typing.Union[
    typing.Literal["append", "ignored"], typing.Any
]
