# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel


class AddPhoneNumbersRequestOutboundConfig(UncheckedBaseModel):
    """
    SIP outbound call configuration.
    """

    address: typing.Optional[str] = pydantic.Field(default=None)
    """
    SIP address. For example `xxx:xxx@sip.example.com`
    """

    transport: typing.Optional[str] = pydantic.Field(default=None)
    """
    Transport protocol. For example `tls`
    """

    prefix: typing.Optional[str] = pydantic.Field(default=None)
    """
    Number prefix. For example `6036`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
