# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel


class UpdatePhoneNumbersResponseAssociatedPipeline(UncheckedBaseModel):
    """
    The associated pipeline information. Returns `null` if no pipeline is associated.
    """

    pipeline_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Pipeline ID.
    """

    pipeline_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Pipeline name.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
