# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .get_history_agents_response_contents_item import GetHistoryAgentsResponseContentsItem


class GetHistoryAgentsResponse(UncheckedBaseModel):
    agent_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique identifier of the agent.
    """

    start_ts: typing.Optional[int] = pydantic.Field(default=None)
    """
    Agent creation timestamp.
    """

    status: typing.Optional[typing.Literal["RUNNING"]] = pydantic.Field(default=None)
    """
    Agent status. Only supports querying the running agent.
    """

    contents: typing.Optional[typing.List[GetHistoryAgentsResponseContentsItem]] = pydantic.Field(default=None)
    """
    Agent history.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
