# This file was auto-generated by Fern from our API Definition.

import typing

StartAgentsRequestPropertiesGeofenceExcludeArea = typing.Union[
    typing.Literal["NORTH_AMERICA", "EUROPE", "ASIA", "INDIA", "JAPAN"], typing.Any
]
