# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel


class CallTelephonyRequestProperties(UncheckedBaseModel):
    """
    Call attribute configuration. The content of this field varies depending on the invocation method:
    - **Using pipeline ID**: Simply pass in `channel`, `token`, `agent_rtc_uid`, and `remote_rtc_uids`.
    - **Using complete configuration**: Pass in the complete parameters of the [Start a conversational AI agent](https://docs.agora.io/en/conversational-ai/rest-api/agent/join) `properties`, including all required fields such as `channel`, `token`, `agent_rtc_uid`, `remote_rtc_uids`, `tts`, and `llm`.
    """

    channel: str = pydantic.Field()
    """
    RTC channel name.
    """

    token: str = pydantic.Field()
    """
    RTC Channel Token.
    """

    agent_rtc_uid: str = pydantic.Field()
    """
    The agent's user ID in the RTC channel.
    """

    remote_rtc_uids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    A list of RTC user IDs. When using pipeline ID, this should contain the SIP gateway UID.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
