# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .start_agents_request_properties_filler_words_trigger_fixed_time_config import (
    StartAgentsRequestPropertiesFillerWordsTriggerFixedTimeConfig,
)


class StartAgentsRequestPropertiesFillerWordsTrigger(UncheckedBaseModel):
    """
    Filler word trigger configuration. Defines when to trigger filler word playback.
    """

    mode: typing.Optional[typing.Literal["fixed_time"]] = pydantic.Field(default=None)
    """
    Filler word trigger mode:
    - `fixed_time`: Fixed time trigger. Triggers filler word playback when LLM response wait time exceeds the threshold.
    """

    fixed_time_config: typing.Optional[StartAgentsRequestPropertiesFillerWordsTriggerFixedTimeConfig] = pydantic.Field(
        default=None
    )
    """
    Fixed time trigger configuration. Used when `mode` is `fixed_time`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
