# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .list_telephony_response_data import ListTelephonyResponseData
from .list_telephony_response_meta import ListTelephonyResponseMeta


class ListTelephonyResponse(UncheckedBaseModel):
    data: ListTelephonyResponseData = pydantic.Field()
    """
    Call data object.
    """

    meta: typing.Optional[ListTelephonyResponseMeta] = pydantic.Field(default=None)
    """
    Metadata about the list.
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    Request status.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
