# This file was auto-generated by Fern from our API Definition.

import typing

ListAgentsResponseDataListItemStatus = typing.Union[
    typing.Literal["IDLE", "STARTING", "RUNNING", "STOPPING", "STOPPED", "RECOVERING", "FAILED"], typing.Any
]
