# This file was auto-generated by Fern from our API Definition.

import typing

StartAgentsRequestPropertiesLlmStyle = typing.Union[typing.Literal["openai", "gemini", "anthropic", "dify"], typing.Any]
