# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .start_agents_request_properties_turn_detection_config_start_of_speech_disabled_config_strategy import (
    StartAgentsRequestPropertiesTurnDetectionConfigStartOfSpeechDisabledConfigStrategy,
)


class StartAgentsRequestPropertiesTurnDetectionConfigStartOfSpeechDisabledConfig(UncheckedBaseModel):
    """
    Disabled mode configuration. Used when `mode` is `disabled`.
    """

    strategy: typing.Optional[StartAgentsRequestPropertiesTurnDetectionConfigStartOfSpeechDisabledConfigStrategy] = (
        pydantic.Field(default=None)
    )
    """
    Voice processing strategy when the agent is interacting:
    - `append`: Human voice does not interrupt the agent. The agent processes the human voice input after the current interaction ends.
    - `ignored`: The agent ignores human voice input and discards it without storing in context.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
