# This file was auto-generated by Fern from our API Definition.

import typing

StartAgentsRequestPropertiesLlmGreetingConfigsMode = typing.Union[
    typing.Literal["single_every", "single_first"], typing.Any
]
