# This file was auto-generated by Fern from our API Definition.

import typing

StartAgentsRequestPropertiesTurnDetectionInterruptMode = typing.Union[
    typing.Literal["interrupt", "append", "ignore", "keyword", "adaptive"], typing.Any
]
