# This file was auto-generated by Fern from our API Definition.

import typing

StartAgentsRequestPropertiesFillerWordsContentStaticConfigSelectionRule = typing.Union[
    typing.Literal["shuffle", "round_robin"], typing.Any
]
