# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .start_agents_response_status import StartAgentsResponseStatus


class StartAgentsResponse(UncheckedBaseModel):
    agent_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique id of the agent instance
    """

    create_ts: typing.Optional[int] = pydantic.Field(default=None)
    """
    Timestamp of when the agent was created
    """

    status: typing.Optional[StartAgentsResponseStatus] = pydantic.Field(default=None)
    """
    Current status:
    - `IDLE` (0): Agent is idle.
    - `STARTING` (1): The agent is being started.
    - `RUNNING` (2): The agent is running.
    - `STOPPING` (3): The agent is stopping.
    - `STOPPED` (4): The agent has exited.
    - `RECOVERING` (5): The agent is recovering.
    - `FAILED` (6): The agent failed to execute.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
