# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .list_agents_response_data_list_item_status import ListAgentsResponseDataListItemStatus


class ListAgentsResponseDataListItem(UncheckedBaseModel):
    start_ts: typing.Optional[int] = pydantic.Field(default=None)
    """
    Agent creation timestamp.
    """

    status: typing.Optional[ListAgentsResponseDataListItemStatus] = pydantic.Field(default=None)
    """
    The current state of the agent.
    """

    agent_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The agent ID.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
