# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .start_agents_request_properties_filler_words_content_static_config import (
    StartAgentsRequestPropertiesFillerWordsContentStaticConfig,
)


class StartAgentsRequestPropertiesFillerWordsContent(UncheckedBaseModel):
    """
    Filler word content configuration. Defines the source and selection rules for filler words.
    """

    mode: typing.Optional[typing.Literal["static"]] = pydantic.Field(default=None)
    """
    Filler word content mode:
    - `static`: Static filler words. Uses a predefined list of filler words.
    """

    static_config: typing.Optional[StartAgentsRequestPropertiesFillerWordsContentStaticConfig] = pydantic.Field(
        default=None
    )
    """
    Static filler word configuration. Used when `mode` is `static`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
