# This file was auto-generated by Fern from our API Definition.

import typing

StartAgentsRequestPropertiesTurnDetectionConfigStartOfSpeechMode = typing.Union[
    typing.Literal["vad", "keywords", "disabled"], typing.Any
]
