# This file was auto-generated by Fern from our API Definition.

import typing

StartAgentsRequestPropertiesAsrVendor = typing.Union[
    typing.Literal[
        "ares", "microsoft", "deepgram", "openai", "google", "amazon", "assemblyai", "speechmatics", "sarvam"
    ],
    typing.Any,
]
