# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class AmazonTtsParams(UncheckedBaseModel):
    """
    Amazon Polly TTS configuration parameters.
    """

    access_key: str = pydantic.Field()
    """
    AWS access key
    """

    secret_key: str = pydantic.Field()
    """
    AWS secret key
    """

    region: str = pydantic.Field()
    """
    AWS region (e.g., "us-east-1")
    """

    voice_id: str = pydantic.Field()
    """
    Amazon Polly voice ID
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
